class CalipelFormBuilder < ActionView::Helpers::FormBuilder

  def field_item(attribute, &block)
    @template.content_tag(:div, class: "control-group #{'error' if errors_present?(attribute)}") do
      label_tag = label(attribute, class: "control-label")
      input = @template.content_tag(:div, class: "controls") do
        yield + errors_on(attribute)
      end
      "#{label_tag}\n#{input}".html_safe
    end
  end

  def errors_on(attribute)
    if errors_present?(attribute)
      @template.content_tag("span",
                            @object.errors[attribute].to_sentence,
                            class: "help-inline")
    end
  end

  def fieldset_item(title, *args, &block)
    @template.content_tag("fieldset", *args) do
      @template.content_tag("legend", title) + @template.content_tag("ul", &block)
    end
  end

  def text_field_item(attribute, *args)
    form_input_item(:text_field, attribute, *args)
  end

  def text_area_item(attribute, *args)
    form_input_item(:text_area, attribute, *args)
  end

  def select_field_item(attribute, options, *args)
    form_input_item(:select, attribute, options, *args)
  end

  private

  def form_input_item(method, attribute, *args)
    field_item(attribute) do
      @template.public_send(method, 
                            @object_name,
                            attribute, 
                            *args)
    end
  end

  def errors_present?(attribute)
    @object.errors[attribute].any?
  end

end
